@@ -21,7 +21,7 @@
 Command line commands.
 """
 
-import asyncssh
+import asyncssh  # type: ignore
 import configparser
 import json
 import os.path
@@ -30,13 +30,14 @@ import typing as tp
 import urllib.request
 from contextlib import asynccontextmanager
 from collections import namedtuple
-from cytoolz.dicttoolz import get_in
+from cytoolz.dicttoolz import get_in  # type: ignore
 from datetime import datetime
 from iterfzf import iterfzf
 from functools import partial
 from uuid import uuid4 as uuid
 
 import remt
+from .data import DocumentItem, Items
 from .error import *
 from .indexer import ann_text, fmt_ann_text
 from .meta import BASE_DIR, fn_path, cache_dir, read_meta, sync_meta, \
@@ -165,7 +166,7 @@ def fn_interactive(ctx: RemtContext, is_dir: bool=False) -> str:
 # parsing pages from a collection of files in reMarkable lines format
 #
 
-def parse_document(ctx, data):
+def parse_document(ctx, data) -> Items:
     get_fin = lambda p: os.path.join(ctx.dir_data, data['uuid'], p) + '.rm'
     pages = data['content'].get('pages')
     if pages is None:
@@ -174,7 +175,7 @@ def parse_document(ctx, data):
     yield from items
 
 
-def parse_page(fin, page_number):
+def parse_page(fin: str, page_number: int) -> Items:
     """
     Parse page from reMarkable lines file.
 
