@@ -21,14 +21,14 @@
 Read and parse reMarkable tablet metadata.
 """
 
-import getmac
+import getmac  # type: ignore
 import glob
 import json
 import logging
 import operator
 import os
-from cytoolz.dicttoolz import assoc
-from cytoolz.functoolz import compose
+from cytoolz.dicttoolz import assoc  # type: ignore
+from cytoolz.functoolz import compose  # type: ignore
 from datetime import datetime
 from functools import partial
 
@@ -82,7 +82,10 @@ def to_path(data, meta):
         return name
 
 def resolve_uuid(meta):
-    meta = {k: assoc(v, 'uuid', k) for k, v in meta.items()}
+    meta = {
+        k: assoc(v, 'uuid', k) for k, v in meta.items()
+        if v.get('parent') != 'trash'
+    }
     return {to_path(data, meta): data for data in meta.values()}
 
 def fn_metadata(meta, path):
