@@ -21,17 +21,17 @@
 PDF utilities.
 """
 
-import gi
+import gi  # type: ignore
 gi.require_version('Poppler', '0.18')  # noqa: E402
 
 import pathlib
-from gi.repository import Poppler
+from gi.repository import Poppler  # type: ignore
 
 from . import const
-from .util import to_point
+from .data import TextSelection
 
 
-def pdf_open(fn):
+def pdf_open(fn: str) -> Poppler.Document:
     """
     Open PDF file and return Poppler library PDF document.
 
@@ -40,7 +40,7 @@ def pdf_open(fn):
     path = pathlib.Path(fn).resolve().as_uri()
     return Poppler.Document.new_from_file(path)
 
-def pdf_scale(page):
+def pdf_scale(page: Poppler.Page) -> float:
     """
     Get scaling factor for a PDF page to fit reMarkable tablet vector data
     onto the page.
@@ -50,40 +50,33 @@ def pdf_scale(page):
     w, h = page.get_size()
     return max(w / const.PAGE_WIDTH, h / const.PAGE_HEIGHT)
 
-def pdf_area(page, stroke):
+def pdf_area(page: Poppler.Page, selection: TextSelection) -> Poppler.Rectangle:
     """
-    Get PDF page area for a stroke.
+    Get PDF page area for a text selection data.
 
     :param page: Poppler PDF page object.
-    :param stroke: reMarkable tablet stroke data.
+    :param selection: Text selection data.
     """
-    to_x = lambda p: to_point(p)[0]
-    to_y = lambda p: to_point(p)[1]
-
-    x1 = min(to_x(s) for s in stroke.segments)
-    x2 = max(to_x(s) for s in stroke.segments)
-    y1 = min(to_y(s) for s in stroke.segments)
-    y2 = max(to_y(s) for s in stroke.segments)
-
     factor = pdf_scale(page)
+    y = selection.y * factor
 
     area = Poppler.Rectangle()
-    area.x1 = (x1 - 15) * factor
-    area.y1 = y1 * factor
-    area.x2 = (x2 + 15) * factor
-    area.y2 = y2 * factor
+    area.x1 = selection.x1 * factor
+    area.y1 = y - 1
+    area.x2 = selection.x2 * factor
+    area.y2 = y + 1
 
     return area
 
-def pdf_text(page, stroke):
+def pdf_text(page: Poppler.Page, selection: TextSelection) -> str:
     """
     Having a reMarkable tablet stroke data, get text annotated by the
     stroke.
 
     :param page: Poppler PDF page object.
-    :param stroke: reMarkable tablet stroke data.
+    :param stroke: Text selection data.
     """
-    area = pdf_area(page, stroke)
+    area = pdf_area(page, selection)
     return page.get_text_for_area(area)
 
 # vim: sw=4:et:ai
