@@ -61,6 +61,8 @@ tilt calculations.
 """
 
 from functools import partial
+
+from .data import PEN_WIDTH_UKNOWN, PEN_WIDTH_HIGHLIGHTER, PEN_WIDTH_ERASE_AREA
 from .util import to_point
 
 def single_line(calc, stroke):
@@ -123,12 +125,12 @@ def calc_width_ballpoint(stroke, segment):
     width = calc_width_fineliner(stroke)
     return width + segment.pressure ** 2048
 
-line_unknown = partial(single_line, lambda s: 1)
+line_unknown = partial(single_line, lambda s: PEN_WIDTH_UKNOWN)
 line_ballpoint = partial(multi_line, calc_width_ballpoint)
 line_fineliner = partial(single_line, calc_width_fineliner)
 line_sharp_pencil = partial(single_line, calc_width_sharp_pencil)
-line_highlighter = partial(single_line, lambda s: 30)
+line_highlighter = partial(single_line, lambda s: PEN_WIDTH_HIGHLIGHTER)
 line_eraser = partial(single_line, calc_width_eraser)
-line_erase_area = partial(single_line, lambda s: 1)
+line_erase_area = partial(single_line, lambda s: PEN_WIDTH_ERASE_AREA)
 
 # vim: sw=4:et:ai
