@@ -23,14 +23,16 @@
 
 from itertools import groupby, chain
 from operator import attrgetter
-from cytoolz.itertoolz import partition
+from cytoolz.itertoolz import partition  # type: ignore
 
 flatten = chain.from_iterable
 to_point = attrgetter('x', 'y')
+to_point_x = attrgetter('x')
+to_point_y = attrgetter('y')
 
 def split(key, seq):
     """
-    Split sequence by a function key./
+    Split sequence by a function key.
 
     :param key: Key function.
     :param seq: Sequence to split.
